# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:rename_success) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  include PuppetX::EnterpriseModules::Oracle::AuditProperty

  desc <<-DESC
    Auditing option for the issuance of a successful RENAME operation on that object.

    here is an example on how to use this:

        ora_object_audit { 'SYS.AUD$@test':
          ensure        => 'present',
          ...
          rename_success => 'on_access',
          ...
        }

    This enables the auditing of successful renames on the table `AUD$` from user `SYS`. An
    audit record is written on every access.

  DESC

  entry('REN')
  data_type("Optional[Enum['absent','none','by_access','by_session']]")
end
