# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:backup_optimization) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `BACKUP OPTIMIZATION`
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      backup_optimization => 'ON',
      ...
    }
  DESC

  newvalues(:clear, :CLEAR, :on, :ON, :off, :OFF)
  data_type("Enum['clear','CLEAR','on','ON','off','OFF','OFF (default)']")

  to_translate_to_resource do |raw_resource|
    raw_resource['BACKUP_OPTIMIZATION']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    rman("configure backup optimization #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
  end
end
