# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:compression_algorithm) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `COMPRESSION ALGORITHM`
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      compression_algorithm => "'HIGH' AS OF RELEASE 'DEFAULT' OPTIMIZE FOR LOAD TRUE",
      ...
    }
  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource['COMPRESSION_ALGORITHM']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    rman("configure compression algorithm #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
  end
end
