# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:rman_output) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `RMAN OUTPUT`.
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      rman_output => 'KEEP FOR 30 DAYS',
      ...
    }
  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource['RMAN_OUTPUT']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    if value.to_s.casecmp('clear').zero?
      rman("configure rman output #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure rman output to #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
