# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:failover_type) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Mungers::Upcase
  include PuppetX::EnterpriseModules::Oracle::ServiceProperty

  desc <<-DESC
    Failover type.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          failover_type => 'SESSION',
          ...
        }

    Puppet provides no default value. But Oracle might, depending on your version.

    This is a cluster only property. On single node database this property will be ignored. If you use it,
    Puppet will issue a warning.

  DESC

  column_name 'Failover type'
  newvalues(:NONE, :SESSION, :SELECT, :TRANSACTION, :AUTO, :none, :session, :select, :transaction, :auto)
  data_type("Optional[Enum['NONE', 'SESSION', 'SELECT', 'TRANSACTION', 'AUTO', 'none', 'session', 'select', 'transaction', 'auto']]")
end
