# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module PuppetX
  module EnterpriseModules
    module Oracle
      # This modules includes all processing needed to allow consistent behaviour
      # for default resources. Specially on a first run.
      module DefaultSid
        def self.included(parent)
          current_version = Gem::Version.new(Puppet.version)
          requested_version = Gem::Version.new('3.6.3')
          if current_version <= requested_version
            parent.send(:define_method, :generate) do
              fill_in_default_sid
              []
            end
          else
            parent.send(:define_method, :pre_run_check) do
              fill_in_default_sid
            end
          end
        end

        def fill_in_default_sid
          return if sid

          #
          # First we check if any ora_setting type is in the catalog. If it is, we use that.
          #
          default_setting = catalog.resources.select { |r| r.type == :ora_setting && r.default.to_s == 'true' }
          #
          # If the search for ora_setting in the catalog didn't find anything, we need to search
          # on. The default can also be a single node ora_database entry in the catalog. Because
          # ora_database also add's content to the ora_settings.yaml file, But DOESN'T
          # create a catalog entry for that.
          #
          default_setting = catalog.resources.select { |r| r.type == :ora_database } if default_setting.empty?
          fail 'You need to specify the sid or specify a ora_setting as default in your manifest' if default_setting.empty?

          sid = default_setting.first[:name]
          self[:name] = if self[:name][-1..-1] == '@'
                          self[:name] + sid
                        else
                          "#{self[:name]}@#{sid}"
                        end
          self[:sid] = sid
        end
      end
    end
  end
end
