# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/command'
require 'puppet_x/enterprisemodules/oracle/settings'
require 'easy_type'

module PuppetX
  module EnterpriseModules
    module Oracle
      # docs
      class OrapwdCommand < PuppetX::EnterpriseModules::Oracle::Command
        include Settings
        include ::EasyType::Encryption
        include ::EasyType::Template

        def initialize(options = {})
          super(:orapwd, options)
        end

        def powershell_script
          # Generate powershell script
          powershell_file = Tempfile.new(['command', '.ps1'])
          ObjectSpace.undefine_finalizer(powershell_file)
          powershell_content = template('ora_config/ora_config/orapwd_command.ps1.erb', binding)
          powershell_file.write(powershell_content)
          powershell_file.close
          powershell_file.path
        end

        def execute(arguments)
          options = { :failonfail => true, :combine => true }
          value = ''
          if Puppet::Util::Platform.windows?
            @oracle_home = configuration_value_for(@sid, 'oracle_home')
            @os_user_pwd = decrypted_value(configuration_value_for(@sid, 'os_user_pwd'))
            @executable = "#{@oracle_home}\\bin\\orapwd.exe"
            @arguments = arguments
            command = %(powershell -File "#{powershell_script}")
          else
            command = command_string(arguments)
          end
          within_time(@timeout) do
            if Puppet::Util::Platform.windows?
              Puppet.debug "orapwd_command.rb: Executing command: #{@command} #{@arguments} as #{@os_user}"
            else
              Puppet.debug "orapwd_command.rb: Executing #{@command} command: #{arguments} as #{os_user}"
            end
            value = Puppet::Util::Execution.execute(command, options)
          end
          value
        end
      end
    end
  end
end
