# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/command'

module PuppetX
  module EnterpriseModules
    module Oracle
      # docs
      class SrvctlCommand < ::PuppetX::EnterpriseModules::Oracle::Command
        def initialize(options = {})
          super(:srvctl, options)
        end

        def execute(arguments)
          # Filter out double '-modifyconfig' and '-n' arguments
          arguments = "#{arguments.split.reject { |a| a.split.any?('-modifyconfig') }.join(' ')} -modifyconfig" if arguments.split.count('-modifyconfig') > 1
          arguments = "#{arguments.split.reject { |a| a.split.any?('-n') }.join(' ')} -n" if arguments.split.count('-n') > 1
          options = { :failonfail => true, :combine => true }
          value = ''
          command = command_string(arguments)
          within_time(@timeout) do
            Puppet.debug "Executing #{@command} command: #{arguments} as #{os_user}"
            value = Puppet::Util::Execution.execute(command, options)
          end
          value
        end
      end
    end
  end
end
